@@ -28,7 +28,10 @@ int get_iface_mac(const char *ifname, char *dst, int len);
 int arp_get(const char *ifname, const char *ip, char *dst, int len);
 
 int allow_destip(const char *ip);
+int deny_destip(const char *ip);
+
 int allow_domain(const char *domain);
+int deny_domain(const char *domain);
 
 int urlencode(char *buf, int blen, const char *src, int slen);
 
@@ -37,5 +40,6 @@ int disable_kmod();
 
 int allow_termianl(const char *mac, const char *token, bool temporary);
 int deny_termianl(const char *mac);
+int whitelist_termianl(const char *mac);
 
 #endif
